@@ -13,6 +13,7 @@ from onnx2tf.utils.common_functions import (
     pre_process_transpose,
     post_process_transpose,
 )
+from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
 
 
 @print_node_info
@@ -72,7 +73,9 @@ def make_node(
             k = 0 - tensor_shape[-2]
     else:
         k = tf.constant(0, dtype=tf.int64)
-    keep_triangle = tf.constant(-1, dtype=k.dtype)
+    k_dtype = NUMPY_DTYPES_TO_TF_DTYPES[k.dtype] \
+        if isinstance(k.dtype, np.dtype) else k.dtype
+    keep_triangle = tf.constant(-1, dtype=k_dtype)
 
     upper = bool(graph_node.attrs.get('upper', 1))
 
